@@ -1,14 +1,14 @@
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-#
-# Copyright (C) 2017, James R. Barlow (https://github.com/jbarlow83/)
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
+
+from __future__ import annotations
+
 import os
 from abc import ABC, abstractmethod
 from pathlib import Path
 from subprocess import DEVNULL, PIPE, CalledProcessError, run
 from tempfile import TemporaryDirectory
-from typing import Optional, cast
+from typing import cast
 
 import deprecation
 from packaging.version import Version
@@ -22,7 +22,7 @@ from pikepdf._exceptions import DependencyError
     deprecated_in="5.1.5", removed_in="6.0", details="Use extract_jbig2_bytes instead"
 )
 def extract_jbig2(
-    im_obj: pikepdf.Object, globals_obj: Optional[pikepdf.Object] = None
+    im_obj: pikepdf.Object, globals_obj: pikepdf.Object | None = None
 ) -> Image.Image:  # pragma: no cover
 
     with TemporaryDirectory(prefix='pikepdf-', suffix='.jbig2') as tmpdir:
