@@ -42,7 +42,7 @@ PDF semantics dictate that setting a dictionary key to Null deletes the key.
 
     d['/Key'] = None  # would delete /Key
 
-For Python users appears to have an unxpected side effect, so this action is
+For Python users appears to have an unexpected side effect, so this action is
 prohibited. You cannot set keys to None.
 
 pikepdf.String is a "type" that can be converted with str() or bytes() as
@@ -115,7 +115,7 @@ bool objecthandle_equal(QPDFObjectHandle self, QPDFObjectHandle other)
         return result;
     }
 
-    // Apart from numeric types, disimilar types are never equal
+    // Apart from numeric types, dissimilar types are never equal
     if (self_typecode != other_typecode)
         return false;
 
@@ -155,7 +155,7 @@ bool objecthandle_equal(QPDFObjectHandle self, QPDFObjectHandle other)
 
         // Early out: if underlying QPDF Buffers happen to be the same, the data is the
         // same
-        if (self_buffer.get() == other_buffer.get())
+        if (self_buffer == other_buffer)
             return true;
         // Early out: if sizes are different, data cannot be the same
         if (self_buffer->getSize() != other_buffer->getSize())
@@ -730,7 +730,7 @@ void init_object(py::module_ &m)
             },
             "Extend a pikepdf.Array with an iterable of other objects.")
         .def_property_readonly("is_rectangle",
-            &QPDFObjectHandle::isRectangle,
+            &QPDFObjectHandle::isRectangle, // LCOV_EXCL_LINE
             "Returns True if the object is a rectangle (an array of 4 numbers)")
         .def(
             "get_stream_buffer",
@@ -817,7 +817,7 @@ void init_object(py::module_ &m)
                 return og.getInstructions();
             })
         .def_static("_parse_stream",
-            &QPDFObjectHandle::parseContentStream,
+            &QPDFObjectHandle::parseContentStream, // LCOV_EXCL_LINE
             "Helper for parsing PDF content stream; use "
             "``pikepdf.parse_content_stream``.")
         .def_static("_parse_stream_grouped",
@@ -967,6 +967,8 @@ void init_object(py::module_ &m)
             Consider instead using :func:`pikepdf.parse_content_stream`.
         )~~~")
         .def(py::init<>(), "You must call ``super.__init__()`` in subclasses.")
+        // LCOV_EXCL_START
+        // coverage misses the virtual function call ::handleObject here.
         .def(
             "handle_object",
             [](QPDFObjectHandle::ParserCallbacks &parsercallbacks,
@@ -979,6 +981,7 @@ void init_object(py::module_ &m)
                 This function will be called back once for each object that is
                 parsed in the content stream.
             )~~~")
+        // LCOV_EXCL_STOP
         .def("handle_eof",
             &QPDFObjectHandle::ParserCallbacks::handleEOF,
             R"~~~(
