@@ -1,3 +1,8 @@
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
+
+from __future__ import annotations
+
 import os.path
 import sys
 from io import BytesIO, FileIO
@@ -20,7 +25,7 @@ def sandwich(resources):
 
 
 class LimitedBytesIO(BytesIO):
-    """Version of BytesIO that only accepts small reads/writes"""
+    """Version of BytesIO that only accepts small reads/writes."""
 
     def write(self, b):
         amt = min(len(b), 100)
@@ -61,7 +66,7 @@ def test_fail_only_overwrite_input_check(monkeypatch, resources, outdir):
 
 
 class BadBytesIO(BytesIO):
-    """Version of BytesIO that reports more bytes written than actual"""
+    """Version of BytesIO that reports more bytes written than actual."""
 
     def write(self, b):
         super().write(b)
@@ -69,7 +74,7 @@ class BadBytesIO(BytesIO):
 
 
 class WrongTypeBytesIO(BytesIO):
-    """Returns wrong type"""
+    """Returns wrong type."""
 
     def write(self, b):  # pylint: disable=unused-argument
         return None  # most likely wrong return type
